# Contour Package

This package provides an ingress controller using [Contour](https://projectcontour.io/).

## Components

* Contour controller
* Envoy reverse proxy and load balancer

## Configuration

You can configure the following:

| Config | Default | Description |
|--------|---------|-------------|
| `infrastructure_provider` | vsphere | The underlying infrastructure provider. Valid values are `vsphere`, `aws` and `azure`. |
| `namespace` | `tanzu-system-ingress` | The namespace in which to deploy Contour and Envoy. |
| `contour.configFileContents` | (none) | The YAML contents of the Contour config file. See [the Contour configuration documentation](https://projectcontour.io/docs/v1.20.2/configuration/#configuration-file) for more information. |
| `contour.replicas` | `2` | How many Contour pod replicas to have. |
| `contour.useProxyProtocol` | `false` | Whether to enable PROXY protocol for all Envoy listeners. |
| `contour.logLevel` | `info` | The Contour log level. Valid values are `info` and `debug`. |
| `contour.pspNames` | `vmware-system-restricted` | A comma-separated list of pod security policies (PSPs) to apply to the Contour pods. |
| `envoy.service.type` | (none) | The type of Kubernetes service to provision for Envoy. Valid values are `LoadBalancer`, `NodePort`, and `ClusterIP`. If not specified, a `NodePort` service will be used for `vsphere` and a `LoadBalancer` for all other infrastructure providers. |
| `envoy.service.externalTrafficPolicy` | (none) | The external traffic policy for the Envoy service. Valid values are `Local` and `Cluster`. If not specified, `Cluster` will be used for `vsphere` and `Local` for all other infrastructure providers. |
| `envoy.service.loadBalancerIP` | (none) | The desired load balancer IP for the Envoy service. If `envoy.service.type` is not `LoadBalancer`, this field is ignored. |
| `envoy.service.annotations` | (none) | Annotations to set on the Envoy service. |
| `envoy.service.nodePorts.http` | (none) | If `envoy.service.type` == `NodePort`, the node port number to expose Envoy's HTTP listener on. If not specified, a node port will be auto-assigned by Kubernetes. |
| `envoy.service.nodePorts.https` | (none) | If `envoy.service.type` == `NodePort`, the node port number to expose Envoy's HTTPS listener on. If not specified, a node port will be auto-assigned by Kubernetes. |
| `envoy.service.aws.LBType` | `classic` | If `infrastructure_provider` == `aws`, the type of AWS load balancer to use. Valid values are `classic` and `nlb`. If not using `aws` this value is ignored. |
| `envoy.hostPorts.enable` | `false` | Whether to enable host ports for the Envoy pods. If false, `envoy.hostPorts.http` and `envoy.hostPorts.https` are ignored. |
| `envoy.hostPorts.http` | `80` | If `envoy.hostPorts.enable` == true, the host port number to expose Envoy's HTTP listener on. |
| `envoy.hostPorts.https` | `443` | If `envoy.hostPorts.enable` == true, the host port number to expose Envoy's HTTPS listener on. |
| `envoy.hostNetwork` | `false` | Whether to enable host networking for the Envoy pods. |
| `envoy.terminationGracePeriodSeconds` | `300` | The termination grace period, in seconds, for the Envoy pods. |
| `envoy.logLevel` | `info` | The Envoy log level. Valid values are `trace`, `debug`, `info`, `warn`, `error`, `critical`, and `off`. |
| `envoy.pspNames` | (none) | A comma-separated list of pod security policies (PSPs) to apply to the Envoy pods. |
| `certificates.duration` | `8760h` |  How long the certificates for securing communication between Contour and Envoy should be valid for. |
| `certificates.renewBefore` | `360h` |  How long before expiration the certificates for securing communication between Contour and Envoy should be renewed. |

## Usage Example

See <https://github.com/vmware-tanzu/community-edition/tree/main/addons/packages/contour#usage-example> for a simple usage example.
